@@ -48,6 +48,7 @@ const fn mix16_b(input: &[u8], input_offset: usize, secret: &[u8], secret_offset
     mul128_fold64(input_lo, input_hi)
 }
 
+#[allow(clippy::too_many_arguments)]
 #[inline]
 const fn mix32_b(mut acc: (u64, u64), input_1: &[u8], input_1_off: usize, input_2: &[u8], input_2_off: usize, secret: &[u8], secret_offset: usize, seed: u64) -> (u64, u64) {
     acc.0 = acc.0.wrapping_add(mix16_b(input_1, input_1_off, secret, secret_offset, seed));
@@ -335,23 +336,9 @@ const fn xxh3_128_9to16(input: &[u8], seed: u64, secret: &[u8]) -> u128 {
 
     mul_low = mul_low.wrapping_add((input.len() as u64 - 1) << 54);
     input_hi ^= flip_hi;
-
-    //Separate code for 32bit and bigger targets
-    //It only makes sense when width is multiple of 2, but if necessary change to simple if
-    //Not to mention I'm not sure you can even compile u128 on something like 16bit?
-    #[cfg(any(target_pointer_width = "32", target_pointer_width = "16", target_pointer_width = "8"))]
-    {
-        mul_high = mul_high.wrapping_add(
-            (input_hi & 0xFFFFFFFF00000000).wrapping_add(mult32_to64(input_hi as u32, xxh32::PRIME_2))
-        );
-    }
-
-    #[cfg(not(any(target_pointer_width = "32", target_pointer_width = "16", target_pointer_width = "8")))]
-    {
-        mul_high = mul_high.wrapping_add(
-            input_hi.wrapping_add(mult32_to64(input_hi as u32, xxh32::PRIME_2 - 1))
-        )
-    }
+    mul_high = mul_high.wrapping_add(
+        input_hi.wrapping_add(mult32_to64(input_hi as u32, xxh32::PRIME_2 - 1))
+    );
 
     mul_low ^= mul_high.swap_bytes();
 
