@@ -37,6 +37,7 @@
 //!
 //!By default all features are off.
 //!
+//!- `std` - Enables `std::io::Write` trait implementation
 //!- `xxh32` - Enables 32bit algorithm. Suitable for x86 targets
 //!- `const_xxh32` - `const fn` version of `xxh32` algorithm
 //!- `xxh64` - Enables 64 algorithm. Suitable for x86_64 targets
@@ -53,6 +54,8 @@
 //!
 //!- SSE2 - widely available, can be safely enabled in 99% of cases. Enabled by default in `x86_64` targets.
 //!- AVX2;
+//!- Neon - Enabled by default on aarch64 targets (most likely);
+//!- Wasm SIMD128 - Has to be enabled via rust flag: `-Ctarget-feature=+simd128`
 //!
 //!## Streaming vs One-shot
 //!
@@ -73,7 +76,13 @@
 
 #![no_std]
 #![warn(missing_docs)]
-#![cfg_attr(feature = "cargo-clippy", allow(clippy::style))]
+#![allow(clippy::style)]
+
+#[cfg(feature = "std")]
+extern crate std;
+
+#[cfg(any(feature = "xxh32", feature = "xxh3", feature = "xxh64"))]
+mod utils;
 
 #[cfg(any(feature = "xxh32", feature = "const_xxh32", feature = "xxh3", feature = "const_xxh3"))]
 mod xxh32_common;
